/*
  TwiKryepad.h

  This file is part of TwiKeypad library for Arduino.

  TwiKeypad library was developed by Synapse(Hiroshi Tanigawa) in 2017.
  This library is originally distributed at "Synapse's history of making
  gadgets." <https://synapse.kyoto>

  TwiKeypad library is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 2.1 of the License, or
  (at your option) any later version.

  TwiKeypad is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with TwiKeypad library.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef TwiKeypad_h
#define TwiKeypad_h

#define TWIKEYPAD_RAM false // characters are stored in RAM
#define TWIKEYPAD_ROM true  // characters are stored in ROM

// Character assignment
extern const char TWIKEYPAD_4X4[16];

#include <avr/pgmspace.h>
#include <arduino.h>
#include "Wire.h"

#define TWIKEYPAD_VERSION 100 // version 1.00

class TwiKeypad
{
private:
  // variables
  TwoWire *ptw; // Pointer to Wire object
  uint8_t TwiAdr; // I2c address
  const char *KeyChar;  // chars assigned to keys
  boolean rom; // indicates if chars are stored in ROM
  uint8_t KeyNum; // number of keys

  //functions
  char KeyToChar(int8_t key);
  int16_t ReadReg(uint8_t RegAdr);
public:
  TwiKeypad() {}
  int8_t begin(TwoWire &tw, uint8_t adr, const char *_KeyChar=NULL, boolean _rom=true);
  int8_t GetKey();
  int8_t WaitForKey();
  char GetChar();
  char WaitForChar();
  int8_t GetKeyNum();
  int16_t GetBoardId();
  int16_t GetFirmVer();
  int8_t SetRepeat(uint8_t RepeatStart, uint8_t RepeatInterval);
  int16_t GetRepeatStart();
  int16_t GetRepeatInterval();
  int8_t GetBufferedKeyNum();
  int8_t ClearBuffer();
  uint32_t GetKeyState();
}; // TwiKeypad

#endif
